==> huaweicloudsdkrds-3.0.52-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/configuration_for_creation.py <==
# coding: utf-8

import re
import six





class ConfigurationForCreation:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'description': 'str',
        'datastore': 'ParaGroupDatastore',
        'values': 'dict(str, str)'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'datastore': 'datastore',
        'values': 'values'
    }

    def __init__(self, name=None, description=None, datastore=None, values=None):
        """ConfigurationForCreation - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._description = None
        self._datastore = None
        self._values = None
        self.discriminator = None

        self.name = name
        if description is not None:
            self.description = description
        self.datastore = datastore
        if values is not None:
            self.values = values

    @property
    def name(self):
        """Gets the name of this ConfigurationForCreation.

        参数模板名称。最长64个字符，只允许大写字母、小写字母、数字、和“-_.”特殊字符。

        :return: The name of this ConfigurationForCreation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConfigurationForCreation.

        参数模板名称。最长64个字符，只允许大写字母、小写字母、数字、和“-_.”特殊字符。

        :param name: The name of this ConfigurationForCreation.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """Gets the description of this ConfigurationForCreation.

        参数模板描述。最长256个字符，不支持>!<\"&'=特殊字符。默认为空。

        :return: The description of this ConfigurationForCreation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ConfigurationForCreation.

        参数模板描述。最长256个字符，不支持>!<\"&'=特殊字符。默认为空。

        :param description: The description of this ConfigurationForCreation.
        :type: str
        """
        self._description = description

    @property
    def datastore(self):
        """Gets the datastore of this ConfigurationForCreation.


        :return: The datastore of this ConfigurationForCreation.
        :rtype: ParaGroupDatastore
        """
        return self._datastore

    @datastore.setter
    def datastore(self, datastore):
        """Sets the datastore of this ConfigurationForCreation.


        :param datastore: The datastore of this ConfigurationForCreation.
        :type: ParaGroupDatastore
        """
        self._datastore = datastore

    @property
    def values(self):
        """Gets the values of this ConfigurationForCreation.

        参数值对象，用户基于默认参数模板自定义的参数值。默认不修改参数值。

        :return: The values of this ConfigurationForCreation.
        :rtype: dict(str, str)
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ConfigurationForCreation.

        参数值对象，用户基于默认参数模板自定义的参数值。默认不修改参数值。

        :param values: The values of this ConfigurationForCreation.
        :type: dict(str, str)
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationForCreation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.54-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/configuration_for_creation.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ConfigurationForCreation:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'description': 'str',
        'datastore': 'ParaGroupDatastore',
        'values': 'dict(str, str)'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'datastore': 'datastore',
        'values': 'values'
    }

    def __init__(self, name=None, description=None, datastore=None, values=None):
        """ConfigurationForCreation - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._description = None
        self._datastore = None
        self._values = None
        self.discriminator = None

        self.name = name
        if description is not None:
            self.description = description
        self.datastore = datastore
        if values is not None:
            self.values = values

    @property
    def name(self):
        """Gets the name of this ConfigurationForCreation.

        参数模板名称。最长64个字符，只允许大写字母、小写字母、数字、和“-_.”特殊字符。

        :return: The name of this ConfigurationForCreation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConfigurationForCreation.

        参数模板名称。最长64个字符，只允许大写字母、小写字母、数字、和“-_.”特殊字符。

        :param name: The name of this ConfigurationForCreation.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """Gets the description of this ConfigurationForCreation.

        参数模板描述。最长256个字符，不支持>!<\"&'=特殊字符。默认为空。

        :return: The description of this ConfigurationForCreation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ConfigurationForCreation.

        参数模板描述。最长256个字符，不支持>!<\"&'=特殊字符。默认为空。

        :param description: The description of this ConfigurationForCreation.
        :type: str
        """
        self._description = description

    @property
    def datastore(self):
        """Gets the datastore of this ConfigurationForCreation.


        :return: The datastore of this ConfigurationForCreation.
        :rtype: ParaGroupDatastore
        """
        return self._datastore

    @datastore.setter
    def datastore(self, datastore):
        """Sets the datastore of this ConfigurationForCreation.


        :param datastore: The datastore of this ConfigurationForCreation.
        :type: ParaGroupDatastore
        """
        self._datastore = datastore

    @property
    def values(self):
        """Gets the values of this ConfigurationForCreation.

        参数值对象，用户基于默认参数模板自定义的参数值。默认不修改参数值。

        :return: The values of this ConfigurationForCreation.
        :rtype: dict(str, str)
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ConfigurationForCreation.

        参数值对象，用户基于默认参数模板自定义的参数值。默认不修改参数值。

        :param values: The values of this ConfigurationForCreation.
        :type: dict(str, str)
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationForCreation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
